@@ -23,7 +23,7 @@ def ensure_output_directory(output_path, settings):
 @click.argument('input_path')
 @click.argument('output_path')
 @click.option('--dry-run/--no-dry-run', default=DEFAULT_SETTINGS.dry_run)
-def command(input_path, output_path, dry_run):
+def _command(input_path, output_path, dry_run):
     """
         Convert a YAML course into a JSON course.
     """
@@ -36,4 +36,4 @@ def command(input_path, output_path, dry_run):
 
 
 if __name__ == '__main__':
-    command()
+    _command()
